<div class="pagination-centered">
{% if users %}
  {% for user in users %}
  <a href="{% url app_forum-userprofile user.username %}">{{user.username}}</a>{% if not forloop.last %}, {% endif %}
  {% endfor %}
and
{% endif %}
{{ anon }} {{ _('anonymous users') }}
</div>
