{% extends "site_base.html" %}

{% load i18n %}
{% load account_tags %}

{% block metas %}
    <title>{{ _('E-mail Address Confirmation') }} - {{ settings.SITE_TITLE }}</title>
{% endblock %}

{% block breadcrumbs %}
{% endblock %}

{% block content %}
    {% user_display email_address.user as user_display %}

<section id="forum">
  {% include "rforum/elements/forum-top.html" %}

  <ul class="breadcrumb">
	<li><i class="icon-user"></i> {% trans "E-mail Address Confirmation" %}</li>
  </ul>

    {% if email_address %}
        <div class="alert alert-success">{% blocktrans with email_address.email as email %}You have confirmed that <a href="mailto:{{email}}">{{ email }}</a> is an e-mail address for user {{ user_display }}.{% endblocktrans %}</div>
    {% else %}
        <div class="alert alert-error">{% trans "Invalid confirmation key." %}</div>
    {% endif %}

</section>
{% endblock %}
