{% extends "site_base.html" %}
{% load thumbnail %}

{% block "metas" %}
    <title>{{ title }} - {{ settings.SITE_TITLE }}</title>
    <meta name="description" content="{{ description|striptags|truncatewords:50 }}" />
{% endblock "metas" %}

{% block "breadcrumbs" %}
  <ul class="breadcrumb">
    <li><i class="icon-home"></i> <a href="{% url app_forum-forum-index %}">{{ _('Forum') }}</a> <span class="divider">/</span></li>
    <li><i class="icon-folder-open"></i> <a href="{% url app_forum-forum-detail mytopic.forum.slug %}">{{ mytopic.forum.title }}</a> <span class="divider">/</span></li>
    <li><i class="icon-file"></i> {{ mytopic.title }}</li>
  </ul>
{% endblock "breadcrumbs" %}

{% block "content" %}
<section id="forum">

  {% include "rforum/_forum-top.html" %}
  {% include "rforum/_actions-topic.html" %}

  <div class="forum">
    <table class="table table-bordered">
      <thead>
        <tr>
          <th colspan="2"><h3>{{ mytopic.title }}</h3></th>
      </thead>
      <tbody>
        {% for post in mypost %}
        <tr>
          <td>
            <a name="{{ post.id }}"></a>
            {{ post.body|safe }}

              {% include "rforum/_actions-post.html" %}

          </td>
          <td style="text-align: center; width: 200px;">
                {% include "rforum/_forum-userdetail.html" %}
          </td>
        </tr>

        {% endfor %}
      </tbody>
    </table>
  </div>

  {% include "rforum/_actions-topic.html" %}
  {% include "rforum/_forum-bottom.html" %}

</section>
{% endblock "content" %}
