{% extends "site_base.html" %}
{% load thumbnail %}

{% block metas %}
    <title>{{ settings.SITE_TITLE }} - {{ settings.SITE_TITLE }}</title>
    <meta name="description" content="{{ settings.SITE_DESCRIPTION }}" />
{% endblock %}

{% block breadcrumbs %}
{% endblock %}

{% block content %}
<section id="forum">
  {% include "app_forum/elements/forum-top.html" %}

  <ul class="breadcrumb">
	<li><i class="icon-user"></i> {{ _('Profile') }}</li>
  </ul>
</section>
{% endblock %}
